@@ -287,7 +287,7 @@
 #' \itemize{
 #' \item `"brie_carre"`: The Brie Carre Pizza (Brie Carre Cheese, Prosciutto,
 #'  Caramelized Onions, Pears, Thyme, Garlic)
-#' \item `"calabrese"`: The Calabrese Pizza (‘Nduja Salami, Pancetta,
+#' \item `"calabrese"`: The Calabrese Pizza ('Nduja Salami, Pancetta,
 #' Tomatoes, Red Onions, Friggitello Peppers, Garlic)
 #' \item `"soppressata"`: The Soppressata Pizza (Soppressata Salami, Fontina
 #' Cheese, Mozzarella Cheese, Mushrooms, Garlic)
@@ -331,10 +331,10 @@
 #' \describe{
 #' \item{id}{The ID for the order, which consists of one or more pizzas at a
 #' given `date` and `time`.}
-#' \item{date}{A character representation of the `order` date, expressed in the
-#' ISO 8601 date format ('YYYY-MM-DD').}
-#' \item{time}{A character representation of the `order` time, expressed as a
-#' 24-hour time the ISO 8601 extended time format ('hh:mm:ss').}
+#' \item{date}{A character representation of the order date, expressed in the
+#' ISO 8601 date format (`YYYY-MM-DD`).}
+#' \item{time}{A character representation of the order time, expressed as a
+#' 24-hour time the ISO 8601 extended time format (`HH:MM:SS`).}
 #' \item{name}{The short name for the pizza.}
 #' \item{size}{The size of the pizza, which can either be `"S"`, `"M"`, `"L"`,
 #' `"XL"` (rare!), or `"XXL"` (even rarer!); most pizzas are available in the
@@ -490,16 +490,120 @@
 #'
 "towny"
 
+#' A table of personal information for people all over the world
+#'
+#' @description
+#'
+#' The `peeps` dataset contains records for one hundred people residing in ten
+#' different countries. Each person in the table has address information along
+#' with their email address and phone number. There are also personal
+#' characteristics like date of birth, height, and weight. This data has been
+#' synthesized, and so the names within the table have not been taken or based
+#' on individuals in real life. The street addresses were generated from actual
+#' street names within real geographic localities, however, the street numbers
+#' were assigned randomly from a constrained number set. While these records do
+#' not relate to real people, efforts were made to make the data as realistic as
+#' possible.
+#'
+#' @format A tibble with 100 rows and 14 variables:
+#' \describe{
+#' \item{name_given, name_family}{The given and family name of individual.}
+#' \item{address}{The street address of the individual.}
+#' \item{city}{The name of the city or locality in which the individual
+#' resides.}
+#' \item{state_prov}{The state or province associated with the `city` and
+#' `address`. This is `NA` for individuals residing in countries where
+#' subdivision data is not needed for generating a valid mailing address.}
+#' \item{postcode}{The post code associated with the `city` and `address`.}
+#' \item{country}{The 3-letter ISO 3166-1 country code representative of the
+#' individual's country.}
+#' \item{email_addr}{The individual's email address.}
+#' \item{phone_number, country_code}{The individual's phone number and the
+#' country code associated with the phone number.}
+#' \item{gender}{The gender of the individual.}
+#' \item{dob}{The individual's date of birth (DOB) in the ISO 8601 form of
+#' `YYYY-MM-DD`.}
+#' \item{height_cm, weight_kg}{The height and weight of the individual in
+#' centimeters (cm) and kilograms (kg), respectively.}
+#' }
+#'
+#' @family datasets
+#' @section Dataset ID and Badge:
+#' DATA-8
+#'
+#' \if{html}{\out{
+#' `r data_get_image_tag(file = "dataset_peeps.png")`
+#' }}
+#'
+#' @section Dataset Introduced:
+#' `v0.11.0`
+#'
+"peeps"
+
+
+#' Feature films in competition at the Cannes Film Festival
+#'
+#' @description
+#'
+#' Each entry in the `films` is a feature film that appeared in the official
+#' selection during a festival year (starting in 1946 and active to the present
+#' day). The `year` column refers to the year of the festival and this figure
+#' doesn't always coincide with the release year of the film. The film's title
+#' reflects the most common title of the film in English, where the
+#' `original_title` column provides the title of the film in its spoken language
+#' (transliterated to Roman script where necessary).
+#'
+#' @format A tibble with 1,851 rows and 8 variables:
+#' \describe{
+#' \item{year}{The year of the festival in which the film was in competition.}
+#' \item{title,original_title}{The `title` field provides the film title used
+#' for English-speaking audiences. The `original_title` field is populated when
+#' `title` differs greatly from the non-English original.}
+#' \item{director}{The director or set of co-directors for the film. Multiple
+#' directors are separated by a comma.}
+#' \item{languages}{The languages spoken in the film in the order of appearance.
+#' This consists of ISO 639 language codes (primarily as two-letter codes, but
+#' using three-letter codes where necessary).}
+#' \item{countries_of_origin}{The country or countries of origin for the
+#' production. Here, 2-letter ISO 3166-1 country codes (set in uppercase) are
+#' used.}
+#' \item{run_time}{The run time of the film in hours and minutes. This is given
+#' as a string in the format `[x]h [y]m`.}
+#' \item{imdb_url}{The URL of the film's information page in the Internet Movie
+#' Database (IMDB).}
+#' }
+#'
+#' @section Examples:
+#'
+#' Here is a glimpse at the data available in `films`.
+#'
+#' ```{r}
+#' dplyr::glimpse(films)
+#' ```
+#'
+#' @family datasets
+#' @section Dataset ID and Badge:
+#' DATA-9
+#'
+#' \if{html}{\out{
+#' `r data_get_image_tag(file = "dataset_films.png")`
+#' }}
+#'
+#' @section Dataset Introduced:
+#' `v0.11.0`
+#'
+"films"
+
 #' The stations of the Paris Metro
 #'
 #' @description
 #'
-#' A dataset with information on all 308 Paris Metro stations as of February
-#' 2023. Each record represents a station, describing which Metro lines are
-#' serviced by the station, which other connections are available, and annual
-#' passenger volumes. Basic location information is provided for each station in
-#' terms where they reside on a municipal level, and, through latitude/longitude
-#' coordinates.
+#' A dataset with information on all 314 Paris Metro stations as of June 2024.
+#' Each record represents a station, describing which Metro lines are serviced
+#' by the station, which other connections are available, and annual passenger
+#' volumes. Basic location information is provided for each station in terms
+#' of where they reside on a municipal level, and, through latitude/longitude
+#' coordinate values.
 #'
 #' The system has 16 lines (numbered from 1 to 14, with two additional lines:
 #' 3bis and 7bis) and covers over 200 kilometers of track. The Metro runs on
@@ -515,7 +619,7 @@
 #' to the Transilien rail network, tramway stations, several major train
 #' stations (e.g., Gare du Nord, Gare de l'Est, etc.), and many bus lines.
 #'
-#' @format A tibble with 308 rows and 11 variables:
+#' @format A tibble with 314 rows and 11 variables:
 #' \describe{
 #' \item{name}{The name of the station.}
 #' \item{caption}{In some cases, a station will have a caption that might
@@ -544,17 +648,9 @@
 #' show `NA` values.}
 #' }
 #'
-#' @section Examples:
-#'
-#' Here is a glimpse at the data available in `metro`.
-#'
-#' ```{r}
-#' dplyr::glimpse(metro)
-#' ```
-#'
 #' @family datasets
 #' @section Dataset ID and Badge:
-#' DATA-8
+#' DATA-10
 #'
 #' \if{html}{\out{
 #' `r data_get_image_tag(file = "dataset_metro.png")`
@@ -565,6 +661,52 @@
 #'
 "metro"
 
+#' Weather conditions in Gibraltar, May 2023
+#'
+#' @description
+#'
+#' The `gibraltar` dataset has meteorological data for the Gibraltar Airport
+#' Station from May 1 to May 31, 2023. Gibraltar is a British Overseas Territory
+#' and city located at the southern end of the Iberian Peninsula, on the Bay of
+#' Gibraltar. This weather station is located at the airport (GIB), where it's
+#' at an elevation of 5 meters above mean sea level (AMSL).
+#'
+#' @format A tibble with 1,431 rows and 10 variables:
+#' \describe{
+#' \item{date, time}{The date and time of the observation.}
+#' \item{temp, dew_point}{The air temperature and dew point values, both in
+#' degrees Celsius.}
+#' \item{humidity}{The relative humidity as a value between `0` and `1`}
+#' \item{wind_dir, wind_speed, wind_gust}{Observations related to wind. The wind
+#' direction is given as the typical 'blowing from' value, simplified to one of
+#' 16 compass directions. The wind speed is provided in units of meters per
+#' second. If there was a measurable wind gust, the maximum gust speed is
+#' recorded as m/s values (otherwise the value is `0`).}
+#' \item{pressure}{The atmospheric pressure in hectopascals (hPa).}
+#' \item{condition}{The weather condition.}
+#' }
+#'
+#' @section Examples:
+#'
+#' Here is a glimpse at the data available in `gibraltar`.
+#'
+#' ```{r}
+#' dplyr::glimpse(gibraltar)
+#' ```
+#'
+#' @family datasets
+#' @section Dataset ID and Badge:
+#' DATA-11
+#'
+#' \if{html}{\out{
+#' `r data_get_image_tag(file = "dataset_gibraltar.png")`
+#' }}
+#'
+#' @section Dataset Introduced:
+#' `v0.11.0`
+#'
+"gibraltar"
+
 #' The fundamental physical constants
 #'
 #' @description
@@ -603,7 +745,7 @@
 #'
 #' @family datasets
 #' @section Dataset ID and Badge:
-#' DATA-9
+#' DATA-12
 #'
 #' \if{html}{\out{
 #' `r data_get_image_tag(file = "dataset_constants.png")`
@@ -696,7 +838,7 @@
 #'
 #' @family datasets
 #' @section Dataset ID and Badge:
-#' DATA-10
+#' DATA-13
 #'
 #' \if{html}{\out{
 #' `r data_get_image_tag(file = "dataset_illness.png")`
@@ -707,6 +849,230 @@
 #'
 "illness"
 
+#' Reaction rates for gas-phase atmospheric reactions of organic compounds
+#'
+#' @description
+#'
+#' The `reactions` dataset contains kinetic data for second-order (two body)
+#' gas-phase chemical reactions for 1,683 organic compounds. The reaction-rate
+#' values and parameters within this dataset are useful for studies of the
+#' atmospheric environment. Organic pollutants, which are present in trace
+#' amounts in the atmosphere, have been extensively studied by research groups
+#' since their persistence in the atmosphere requires specific attention. Many
+#' researchers have reported kinetic data on specific gas-phase reactions and
+#' these mainly involve oxidation reactions with OH, nitrate radicals, ozone,
+#' and chlorine atoms.
+#'
+#' This compilation of rate constant (*k*) data as contains the values for rate
+#' constants at 298 K (in units of `cm^3 molecules^-1 s^-1`) as well as
+#' parameters that allow for the calculation of rate constants at different
+#' temperatures (the temperature dependence parameters: `A`, `B`, and `n`).
+#' Uncertainty values/factors and temperature limits are also provided here
+#' where information is available.
+#'
+#' @format A tibble with 1,683 rows and 39 variables:
+#' \describe{
+#' \item{compd_name}{The name of the primary compound undergoing
+#' reaction with OH, ozone, NO3, or Cl.}
+#' \item{cmpd_mwt}{The molecular weight of the compound in units of g/mol.}
+#' \item{cmpd_formula}{The chemical formula of the compound.}
+#' \item{cmpd_type}{The category of compounds that the `compd_name` falls
+#' under.}
+#' \item{cmpd_smiles}{The SMILES (simplified molecular-input line-entry system)
+#' representation for the compound.}
+#' \item{cmpd_inchi}{The InChI (International Chemical Identifier)
+#' representation for the compound.}
+#' \item{cmpd_inchikey}{The InChIKey, which is a hashed InChI value, has a fixed
+#' length of 27 characters. These values can be used to more easily perform
+#' database searches of chemical compounds.}
+#' \item{OH_k298}{Rate constant at 298 K for OH reactions.}
+#' \item{OH_uncert}{Uncertainty as a percentage for certain OH reactions.}
+#' \item{OH_u_fac}{Uncertainty as a plus/minus difference for certain OH
+#' reactions.}
+#' \item{OH_a, OH_b, OH_n}{Extended temperature dependence parameters for
+#' bimolecular OH reactions, to be used in the Arrhenius expression:
+#' `k(T)=A exp(-B/T) (T/300)^n`. In that, `A` is expressed as
+#' cm^3 molecules^-1 s^-1, `B` is in units of K, and `n` is dimensionless. Any
+#' `NA` values indicate that data is not available.}
+#' \item{OH_t_low, OH_t_high}{The low and high temperature boundaries (in units
+#' of K) for which the `OH_a`, `OH_b`, and `OH_n` parameters are valid.}
+#' \item{O3_k298}{Rate constant at 298 K for ozone reactions.}
+#' \item{O3_uncert}{Uncertainty as a percentage for certain ozone reactions.}
+#' \item{O3_u_fac}{Uncertainty as a plus/minus difference for certain ozone
+#' reactions.}
+#' \item{O3_a, O3_b, O3_n}{Extended temperature dependence parameters for
+#' bimolecular ozone reactions, to be used in the Arrhenius expression:
+#' `k(T)=A exp(-B/T) (T/300)^n`. In that, `A` is expressed as
+#' cm^3 molecules^-1 s^-1, `B` is in units of K, and `n` is dimensionless. Any
+#' `NA` values indicate that data is not available.}
+#' \item{O3_t_low, O3_t_high}{The low and high temperature boundaries (in units
+#' of K) for which the `O3_a`, `O3_b`, and `O3_n` parameters are valid.}
+#' \item{NO3_k298}{Rate constant at 298 K for NO3 reactions.}
+#' \item{NO3_uncert}{Uncertainty as a percentage for certain NO3 reactions.}
+#' \item{NO3_u_fac}{Uncertainty as a plus/minus difference for certain NO3
+#' reactions.}
+#' \item{NO3_a, NO3_b, NO3_n}{Extended temperature dependence parameters for
+#' bimolecular NO3 reactions, to be used in the Arrhenius expression:
+#' `k(T)=A exp(-B/T) (T/300)^n`. In that, `A` is expressed as
+#' cm^3 molecules^-1 s^-1, `B` is in units of K, and `n` is dimensionless. Any
+#' `NA` values indicate that data is not available.}
+#' \item{NO3_t_low, NO3_t_high}{The low and high temperature boundaries (in
+#' units of K) for which the `NO3_a`, `NO3_b`, and `NO3_n` parameters are
+#' valid.}
+#' \item{Cl_k298}{Rate constant at 298 K for Cl reactions.}
+#' \item{Cl_uncert}{Uncertainty as a percentage for certain Cl reactions.}
+#' \item{Cl_u_fac}{Uncertainty as a plus/minus difference for certain Cl
+#' reactions.}
+#' \item{Cl_a, Cl_b, Cl_n}{Extended temperature dependence parameters for
+#' bimolecular Cl reactions, to be used in the Arrhenius expression:
+#' `k(T)=A exp(-B/T) (T/300)^n`. In that, `A` is expressed as
+#' cm^3 molecules^-1 s^-1, `B` is in units of K, and `n` is dimensionless. Any
+#' `NA` values indicate that data is not available.}
+#' \item{Cl_t_low, Cl_t_high}{The low and high temperature boundaries (in units
+#' of K) for which the `Cl_a`, `Cl_b`, and `Cl_n` parameters are valid.}
+#' }
+#'
+#' @section Examples:
+#'
+#' Here is a glimpse at the data available in `reactions`.
+#'
+#' ```{r}
+#' dplyr::glimpse(reactions)
+#' ```
+#'
+#' @family datasets
+#' @section Dataset ID and Badge:
+#' DATA-14
+#'
+#' \if{html}{\out{
+#' `r data_get_image_tag(file = "dataset_reactions.png")`
+#' }}
+#'
+#' @section Dataset Introduced:
+#' `v0.11.0`
+#'
+"reactions"
+
+#' Data on photolysis rates for gas-phase organic compounds
+#'
+#' @description
+#'
+#' The `photolysis` dataset contains numerical values for describing the
+#' photolytic degradation pathways of 25 compounds of relevance in atmospheric
+#' chemistry. Many volatile organic compounds (VOCs) are emitted in substantial
+#' quantities from both biogenic and anthropogenic sources, and they can have a
+#' major influence on the chemistry of the lower atmosphere. A portion of these
+#' can be transformed into other VOCs via the energy provided from light.
+#'
+#' In order to realistically predict the composition of the atmosphere and how
+#' it evolves over time, we need accurate estimates of photolysis rates. The
+#' data provided here in `photolysis` allows for computations of photolysis
+#' rates (*J*, having units of `s^-1`) as a function of the solar zenith angle
+#' (SZA). Having such values is essential when deploying atmospheric chemistry
+#' models.
+#'
+#' @format A tibble with 34 rows and 10 variables:
+#' \describe{
+#' \item{compd_name}{The name of the primary compound undergoing photolysis.}
+#' \item{cmpd_formula}{The chemical formula of the compound.}
+#' \item{products}{A product pathway for the photolysis of the compound.}
+#' \item{type}{The type of organic compound undergoing photolysis.}
+#' \item{l, m, n}{The parameter values given in the `l`, `m`, and `n` columns
+#' can be used to calculate the photolysis rate (*J*) as a function of the
+#' solar zenith angle (*X*, in radians) through the expression:
+#' `J = l * cos(X)^m * exp(-n * sec(X))`.}
+#' \item{quantum_yield}{In the context of photolysis reactions, this is the
+#' efficiency of a given photolytic reaction. In other words, it's the number of
+#' product molecules formed over the number of photons absorbed.}
+#' \item{wavelength_nm, sigma_298_cm2}{The `wavelength_nm` and `sigma_298_cm2`
+#' columns provide photoabsorption data for the compound undergoing photolysis.
+#' The values in `wavelength_nm` provide the wavelength of light in nanometer
+#' units; the `sigma_298_cm2` values are paired with the `wavelength_nm` values
+#' and they are in units of `cm^2 molecule^-1`.}
+#' }
+#'
+#' @section Examples:
+#'
+#' Here is a glimpse at the data available in `photolysis`.
+#'
+#' ```{r}
+#' dplyr::glimpse(photolysis)
+#' ```
+#'
+#' @family datasets
+#' @section Dataset ID and Badge:
+#' DATA-15
+#'
+#' \if{html}{\out{
+#' `r data_get_image_tag(file = "dataset_photolysis.png")`
+#' }}
+#'
+#' @section Dataset Introduced:
+#' `v0.11.0`
+#'
+"photolysis"
+
+#' Nuclide data
+#'
+#' @description
+#'
+#' The `nuclides` dataset contains information on all known nuclides, providing
+#' data on nuclear structure and decay modes across 118 elements. There is data
+#' here on natural abundances, atomic mass, spin, half-life, and more. The
+#' typical users for such a dataset include researchers in fields such as
+#' nuclear physics, radiochemistry, and nuclear medicine.
+#'
+#' @format A tibble with 3,383 rows and 29 variables:
+#' \describe{
+#' \item{nuclide}{The symbol for the nuclide.}
+#' \item{z, n}{The number of protons and neutrons.}
+#' \item{element}{The element symbol.}
+#' \item{radius, radius_uncert}{The charge radius and its associated
+#' uncertainty. In units of fm.}
+#' \item{abundance, abundance_uncert}{The abundance of the stable isotope as
+#' a mole fraction (in relation to other stable isotopes of the same element).
+#' Values are provided for the nuclide only if `is_stable` is `TRUE`.}
+#' \item{is_stable}{Is the nuclide a stable isotope?}
+#' \item{half_life, half_life_uncert}{The nuclide's half life represented as
+#' seconds.}
+#' \item{isospin}{The isospin, or the quantum number related to the up and down
+#' quark content of the particle.}
+#' \item{decay_1, decay_2, decay_3}{The 1st, 2nd, and 3rd decay modes.}
+#' \item{decay_1_pct, decay_1_pct_uncert, decay_2_pct, decay_2_pct_uncert,
+#' decay_3_pct, decay_3_pct_uncert}{The branching proportions for the 1st, 2nd,
+#' and 3rd decays (along with uncertainty values).}
+#' \item{magnetic_dipole, magnetic_dipole_uncert}{The magnetic dipole and its
+#' associated uncertainty. Expressed in units of micro N, or nuclear
+#' magneton values.}
+#' \item{electric_quadrupole, electric_quadrupole_uncert}{The electric
+#' quadrupole and its associated uncertainty. In units of barn (b).}
+#' \item{atomic_mass, atomic_mass_uncert}{The atomic mass and its associated
+#' uncertainty. In units of micro AMU.}
+#' \item{mass_excess, mass_excess_uncert}{The mass excess and its associated
+#' uncertainty. In units of keV.}
+#' }
+#'
+#' @section Examples:
+#'
+#' Here is a glimpse at the data available in `nuclides`.
+#'
+#' ```{r}
+#' dplyr::glimpse(nuclides)
+#' ```
+#'
+#' @family datasets
+#' @section Dataset ID and Badge:
+#' DATA-16
+#'
+#' \if{html}{\out{
+#' `r data_get_image_tag(file = "dataset_nuclides.png")`
+#' }}
+#'
+#' @section Dataset Introduced:
+#' `v0.11.0`
+#'
+"nuclides"
+
 #' An ADSL-flavored clinical trial toy dataset
 #'
 #' @description
@@ -766,7 +1132,7 @@
 #'
 #' @family datasets
 #' @section Dataset ID and Badge:
-#' DATA-11
+#' DATA-17
 #'
 #' \if{html}{\out{
 #' `r data_get_image_tag(file = "dataset_rx_adsl.png")`
@@ -839,7 +1205,7 @@
 #'
 #' @family datasets
 #' @section Dataset ID and Badge:
-#' DATA-12
+#' DATA-18
 #'
 #' \if{html}{\out{
 #' `r data_get_image_tag(file = "dataset_rx_addv.png")`
