@@ -21,39 +21,6 @@
 #
 #------------------------------------------------------------------------------#
 
-
-#nocov start
-
-register_s3_method <- function(
-    pkg,
-    generic,
-    class,
-    fun = NULL
-) {
-
-  stopifnot(is.character(pkg), length(pkg) == 1)
-  stopifnot(is.character(generic), length(generic) == 1)
-  stopifnot(is.character(class), length(class) == 1)
-
-  if (is.null(fun)) {
-    fun <- get(paste0(generic, ".", class), envir = parent.frame())
-  } else {
-    stopifnot(is.function(fun))
-  }
-
-  if (pkg %in% loadedNamespaces()) {
-    registerS3method(generic, class, fun, envir = asNamespace(pkg))
-  }
-
-  # Always register hook in case package is later unloaded & reloaded
-  setHook(
-    packageEvent(pkg, "onLoad"),
-    function(...) {
-      registerS3method(generic, class, fun, envir = asNamespace(pkg))
-    }
-  )
-}
-
 utils::globalVariables(
   c(
     ".",
@@ -77,6 +44,8 @@ utils::globalVariables(
     "copyright",
     "curr_code",
     "curr_name",
+    "curr_number",
+    "curr_symbol",
     "data_attr",
     "date_added",
     "decimal",
@@ -88,6 +57,7 @@ utils::globalVariables(
     "footnotes_to_list",
     "formatted",
     "format_code",
+    "format_name",
     "fs_id",
     "fs_id_coalesced",
     "get_groups_rows",
@@ -106,6 +76,7 @@ utils::globalVariables(
     "label",
     "locname",
     "locnum",
+    "lw",
     "missing_text",
     "n",
     "n_cols",
@@ -139,6 +110,7 @@ utils::globalVariables(
     "parameter",
     "property",
     "property_value",
+    "pt",
     "r",
     "rgba",
     "rowname",
@@ -186,32 +158,15 @@ gt_default_options <-
   list(
     gt.row_group.sep = " - ",
     gt.html_tag_check = TRUE,
-    gt.strict_column_fmt = FALSE,
-    gt.latex_packages = c("booktabs", "caption", "longtable", "colortbl", "array")
+    gt.latex_packages = c("booktabs", "caption", "longtable", "colortbl", "array", "anyfontsize", "multirow")
   )
 
-# R 3.5 and earlier have a bug on Windows where if x is latin1 or unknown and
-# replacement is UTF-8, the UTF-8 bytes are inserted into the result but the
-# result is not marked as UTF-8.
-# Example: gsub("a", "\u00B1", "a", fixed = TRUE)
-utf8_aware_sub <- NULL
-
 .onLoad <- function(libname, pkgname, ...) {
 
-  register_s3_method("knitr", "knit_print", "gt_tbl")
-  register_s3_method("knitr", "knit_print", "gt_group")
-  register_s3_method("htmltools", "as.tags", "gt_tbl")
-
   op <- options()
   toset <- !(names(gt_default_options) %in% names(op))
   if (any(toset)) options(gt_default_options[toset])
 
-  utf8_aware_sub <<-
-    identical(
-      "UTF-8",
-      Encoding(sub(".", "\u00B1", ".", fixed = TRUE))
-    )
-
   invisible()
 }
 
