@@ -28,7 +28,7 @@ time_tbl <-
 # `data_tbl` dataset
 tab_time <- gt(time_tbl)
 
-test_that("The `fmt_number()` function works with conditional `rows`", {
+test_that("fmt_number() works with conditional `rows`", {
 
   expect_equal(
     (tab %>%
@@ -50,7 +50,7 @@ test_that("The `fmt_number()` function works with conditional `rows`", {
     c("34.0000", "74", "23", "NA", "35", "NA", "NA"))
 })
 
-test_that("The `fmt_scientific()` function works with conditional `rows`", {
+test_that("fmt_scientific() works with conditional `rows`", {
 
   expect_equal(
     (tab %>%
@@ -61,11 +61,11 @@ test_that("The `fmt_scientific()` function works with conditional `rows`", {
        render_formats_test(context = "html"))[["num_1"]],
     c(
       "1836.23", "2763.39",
-      paste0("9.3729 ", "\U000D7", " 10<sup style='font-size: 65%;'>2</sup>"),
-      paste0("6.4300 ", "\U000D7", " 10<sup style='font-size: 65%;'>2</sup>"),
-      paste0("2.1223 ", "\U000D7", " 10<sup style='font-size: 65%;'>2</sup>"),
+      paste0("9.3729&nbsp;", "\U000D7", "&nbsp;10<sup style='font-size: 65%;'>2</sup>"),
+      paste0("6.4300&nbsp;", "\U000D7", "&nbsp;10<sup style='font-size: 65%;'>2</sup>"),
+      paste0("2.1223&nbsp;", "\U000D7", "&nbsp;10<sup style='font-size: 65%;'>2</sup>"),
       "0.0000",
-      paste0("\U02212", "2.3240 ", "\U000D7", " 10<sup style='font-size: 65%;'>1</sup>")
+      paste0("\U02212", "2.3240&nbsp;", "\U000D7", "&nbsp;10<sup style='font-size: 65%;'>1</sup>")
     )
   )
 
@@ -77,13 +77,13 @@ test_that("The `fmt_scientific()` function works with conditional `rows`", {
          rows = char_2 %in% c("june", "july") & grepl("sa.*", char_1)) %>%
        render_formats_test(context = "html"))[["num_2"]],
     c(
-      paste0("3.4000 ", "\U000D7", " 10<sup style='font-size: 65%;'>1</sup>"),
+      paste0("3.4000&nbsp;", "\U000D7", "&nbsp;10<sup style='font-size: 65%;'>1</sup>"),
       "74", "23", "NA", "35", "NA", "NA"
     )
   )
 })
 
-test_that("The `fmt_percent()` function works with conditional `rows`", {
+test_that("fmt_percent() works with conditional `rows`", {
 
   expect_equal(
     (tab %>%
@@ -110,7 +110,7 @@ test_that("The `fmt_percent()` function works with conditional `rows`", {
   )
 })
 
-test_that("The `fmt_currency()` function works with conditional `rows`", {
+test_that("fmt_currency() works with conditional `rows`", {
 
   expect_equal(
     (tab %>%
@@ -136,7 +136,7 @@ test_that("The `fmt_currency()` function works with conditional `rows`", {
   )
 })
 
-test_that("The `fmt_date()` function works with conditional `rows`", {
+test_that("fmt_date() works with conditional `rows`", {
 
   expect_equal(
     (tab_time %>%
@@ -159,7 +159,7 @@ test_that("The `fmt_date()` function works with conditional `rows`", {
   )
 })
 
-test_that("The `fmt_time()` function works with conditional `rows`", {
+test_that("fmt_time() works with conditional `rows`", {
 
   expect_equal(
     (tab_time %>%
@@ -182,7 +182,7 @@ test_that("The `fmt_time()` function works with conditional `rows`", {
   )
 })
 
-test_that("The `fmt_datetime()` function works with conditional `rows`", {
+test_that("fmt_datetime() works with conditional `rows`", {
 
   expect_equal(
     (tab_time %>%
@@ -209,7 +209,7 @@ test_that("The `fmt_datetime()` function works with conditional `rows`", {
   )
 })
 
-test_that("The `fmt_passthrough()` function works with conditional `rows`", {
+test_that("fmt_passthrough() works with conditional `rows`", {
 
   expect_equal(
     (tab_time %>%
@@ -232,7 +232,7 @@ test_that("The `fmt_passthrough()` function works with conditional `rows`", {
   )
 })
 
-test_that("The `sub_missing()` function works with conditional `rows`", {
+test_that("sub_missing() works with conditional `rows`", {
 
   expect_equal(
     (tab %>%
@@ -245,7 +245,7 @@ test_that("The `sub_missing()` function works with conditional `rows`", {
   )
 })
 
-test_that("The `fmt()` function works with conditional `rows`", {
+test_that("fmt() works with conditional `rows`", {
 
   expect_equal(
     (tab %>%
